@@ -8,13 +8,11 @@
 #'
 #' @export
 msigdbr_collections <- function(db_species = "Hs") {
-  # Check if msigdbdf is available and try to install otherwise
-  msigdbr_check_data()
-
   # Get the full table of gene sets and their member genes
-  mc <- msigdbdf::msigdbdf(target_species = db_species)
+  mc <- load_msigdb_df(target_species = db_species)
+  mc <- tibble::as_tibble(mc)
 
-  # Keep only gene set information (ignors genes)
+  # Keep only gene set information (ignore genes)
   mc <- dplyr::distinct(
     mc,
     .data$gs_collection,
